"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanBody = scanBody;
const checkDetectors_1 = require("../utils/functions/checkDetectors");
/**
 * Escanea el cuerpo de una solicitud HTTP y busca posibles problemas de seguridad.
 *
 * @param body - El cuerpo de la solicitud HTTP.
 * @param options - Opciones de escaneo.
 * @returns Un array de cadenas que representan los problemas encontrados en el escaneo.
 *
 * @remarks
 * Esta función escanea el cuerpo de una solicitud HTTP en busca de posibles problemas de seguridad.
 * Puede escanear las claves y/o los valores del cuerpo, dependiendo de las opciones proporcionadas.
 * Los problemas encontrados se agregan a un array y se devuelven al final del escaneo.
 * @author Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
function scanBody(body, options) {
    const issues = [];
    const { keys, values } = options;
    if (keys) {
        Object.keys(body).forEach((key) => {
            (0, checkDetectors_1.checkDetectors)(key, key, issues, options, true);
        });
    }
    if (values) {
        Object.entries(body).forEach(([key, value]) => {
            (0, checkDetectors_1.checkDetectors)(value, key, issues, options);
        });
    }
    return issues;
}
//# sourceMappingURL=scanBody.js.map